@@ -1,11 +1,12 @@
 import logging
 
+from borgmatic.borg import environment, flags
 from borgmatic.execute import execute_command
 
 logger = logging.getLogger(__name__)
 
 
-def _make_prune_flags(retention_config):
+def make_prune_flags(retention_config):
     '''
     Given a retention config dict mapping from option name to value, tranform it into an iterable of
     command-line name-value flag pairs.
@@ -22,11 +23,9 @@ def _make_prune_flags(retention_config):
         )
     '''
     config = retention_config.copy()
-
-    if 'prefix' not in config:
-        config['prefix'] = '{hostname}-'
-    elif not config['prefix']:
-        config.pop('prefix')
+    prefix = config.pop('prefix', '{hostname}-')
+    if prefix:
+        config['glob_archives'] = f'{prefix}*'
 
     return (
         ('--' + option_name.replace('_', '-'), str(value)) for option_name, value in config.items()
@@ -38,10 +37,11 @@ def prune_archives(
     repository,
     storage_config,
     retention_config,
+    local_borg_version,
     local_path='borg',
     remote_path=None,
     stats=False,
-    files=False,
+    list_archives=False,
 ):
     '''
     Given dry-run flag, a local or remote repository path, a storage config dict, and a
@@ -54,22 +54,27 @@ def prune_archives(
 
     full_command = (
         (local_path, 'prune')
-        + tuple(element for pair in _make_prune_flags(retention_config) for element in pair)
+        + tuple(element for pair in make_prune_flags(retention_config) for element in pair)
         + (('--remote-path', remote_path) if remote_path else ())
         + (('--umask', str(umask)) if umask else ())
         + (('--lock-wait', str(lock_wait)) if lock_wait else ())
         + (('--stats',) if stats and not dry_run else ())
         + (('--info',) if logger.getEffectiveLevel() == logging.INFO else ())
-        + (('--list',) if files else ())
+        + (('--list',) if list_archives else ())
         + (('--debug', '--show-rc') if logger.isEnabledFor(logging.DEBUG) else ())
         + (('--dry-run',) if dry_run else ())
         + (tuple(extra_borg_options.split(' ')) if extra_borg_options else ())
-        + (repository,)
+        + flags.make_repository_flags(repository, local_borg_version)
     )
 
-    if (stats or files) and logger.getEffectiveLevel() == logging.WARNING:
+    if (stats or list_archives) and logger.getEffectiveLevel() == logging.WARNING:
         output_log_level = logging.WARNING
     else:
         output_log_level = logging.INFO
 
-    execute_command(full_command, output_log_level=output_log_level, error_on_warnings=False)
+    execute_command(
+        full_command,
+        output_log_level=output_log_level,
+        borg_local_path=local_path,
+        extra_environment=environment.make_environment(storage_config),
+    )
